==> openshift-model-5.9.0-sources.jar: io/fabric8/openshift/api/model/SecretSpecFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent;

 /**
  * Generated
  */
public interface SecretSpecFluent<A extends io.fabric8.openshift.api.model.SecretSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getMountPath();
  public A withMountPath(java.lang.String mountPath);
  public java.lang.Boolean hasMountPath();
  
  /**
   * Method is deprecated. use withMountPath instead.
   */
  @java.lang.Deprecated
  public A withNewMountPath(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildSecretSource instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LocalObjectReference getSecretSource();
  public io.fabric8.kubernetes.api.model.LocalObjectReference buildSecretSource();
  public A withSecretSource(io.fabric8.kubernetes.api.model.LocalObjectReference secretSource);
  public java.lang.Boolean hasSecretSource();
  public A withNewSecretSource(java.lang.String name);
  public io.fabric8.openshift.api.model.SecretSpecFluent.SecretSourceNested<A> withNewSecretSource();
  public io.fabric8.openshift.api.model.SecretSpecFluent.SecretSourceNested<A> withNewSecretSourceLike(io.fabric8.kubernetes.api.model.LocalObjectReference item);
  public io.fabric8.openshift.api.model.SecretSpecFluent.SecretSourceNested<A> editSecretSource();
  public io.fabric8.openshift.api.model.SecretSpecFluent.SecretSourceNested<A> editOrNewSecretSource();
  public io.fabric8.openshift.api.model.SecretSpecFluent.SecretSourceNested<A> editOrNewSecretSourceLike(io.fabric8.kubernetes.api.model.LocalObjectReference item);
  public interface SecretSourceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent<io.fabric8.openshift.api.model.SecretSpecFluent.SecretSourceNested<N>>{
    public N and();
    public N endSecretSource();
    
  }
  
}

==> openshift-model-5.12.0-sources.jar: io/fabric8/openshift/api/model/SecretSpecFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceBuilder;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.model.LocalObjectReference;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;
import io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent;

 /**
  * Generated
  */
public interface SecretSpecFluent<A extends io.fabric8.openshift.api.model.SecretSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public java.lang.String getMountPath();
  public A withMountPath(java.lang.String mountPath);
  public java.lang.Boolean hasMountPath();
  
  /**
   * Method is deprecated. use withMountPath instead.
   */
  @java.lang.Deprecated
  public A withNewMountPath(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildSecretSource instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LocalObjectReference getSecretSource();
  public io.fabric8.kubernetes.api.model.LocalObjectReference buildSecretSource();
  public A withSecretSource(io.fabric8.kubernetes.api.model.LocalObjectReference secretSource);
  public java.lang.Boolean hasSecretSource();
  public A withNewSecretSource(java.lang.String name);
  public io.fabric8.openshift.api.model.SecretSpecFluent.SecretSourceNested<A> withNewSecretSource();
  public io.fabric8.openshift.api.model.SecretSpecFluent.SecretSourceNested<A> withNewSecretSourceLike(io.fabric8.kubernetes.api.model.LocalObjectReference item);
  public io.fabric8.openshift.api.model.SecretSpecFluent.SecretSourceNested<A> editSecretSource();
  public io.fabric8.openshift.api.model.SecretSpecFluent.SecretSourceNested<A> editOrNewSecretSource();
  public io.fabric8.openshift.api.model.SecretSpecFluent.SecretSourceNested<A> editOrNewSecretSourceLike(io.fabric8.kubernetes.api.model.LocalObjectReference item);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface SecretSourceNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LocalObjectReferenceFluent<io.fabric8.openshift.api.model.SecretSpecFluent.SecretSourceNested<N>>{
    public N and();
    public N endSecretSource();
    
  }
  
}
